package Localizer;
use 5.008005;
use strict;
use warnings;

our $VERSION = "0.03";

1;
__END__

=encoding utf-8

=head1 NAME

Localizer - Yet another framework for localization

=head1 DESCRIPTION

See L<Localizer::Resource>

=head1 LICENSE

Copyright (C) Tokuhiro Matsuno.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

Tokuhiro Matsuno E<lt>tokuhirom@gmail.comE<gt>

moznion E<lt>moznion@gmail.comE<gt>

=cut

